summaryrefslogtreecommitdiffstats
path: root/lib/private/Files/Filesystem.php
diff options
context:
space:
mode:
authorCôme Chilliet <come.chilliet@nextcloud.com>2023-03-13 18:33:12 +0100
committerCôme Chilliet <come.chilliet@nextcloud.com>2023-04-03 10:52:33 +0200
commit966a3e696335d9dad2cc8dfa2ec44d44298626ff (patch)
tree491f4b36f976560431ac336c06f8d613ca401ca7 /lib/private/Files/Filesystem.php
parent8e529df6ae5dfb5df987919d11a49828e19f6dbc (diff)
downloadnextcloud-server-966a3e696335d9dad2cc8dfa2ec44d44298626ff.tar.gz
nextcloud-server-966a3e696335d9dad2cc8dfa2ec44d44298626ff.zip
Tidy up typing in OC\Files\View
Signed-off-by: Côme Chilliet <come.chilliet@nextcloud.com>
Diffstat (limited to 'lib/private/Files/Filesystem.php')
-rw-r--r--lib/private/Files/Filesystem.php65
1 files changed, 23 insertions, 42 deletions
diff --git a/lib/private/Files/Filesystem.php b/lib/private/Files/Filesystem.php
index 500a13b1f9d..7067ddf4a95 100644
--- a/lib/private/Files/Filesystem.php
+++ b/lib/private/Files/Filesystem.php
@@ -42,6 +42,7 @@ use OC\Files\Mount\MountPoint;
use OC\User\NoUserException;
use OCP\EventDispatcher\IEventDispatcher;
use OCP\Files\Events\Node\FilesystemTornDownEvent;
+use OCP\Files\Mount\IMountManager;
use OCP\Files\NotFoundException;
use OCP\Files\Storage\IStorageFactory;
use OCP\IUser;
@@ -49,25 +50,16 @@ use OCP\IUserManager;
use OCP\IUserSession;
class Filesystem {
- /**
- * @var Mount\Manager $mounts
- */
- private static $mounts;
-
- public static $loaded = false;
- /**
- * @var \OC\Files\View $defaultInstance
- */
- private static $defaultInstance;
+ private static ?Mount\Manager $mounts = null;
- private static $usersSetup = [];
+ public static bool $loaded = false;
- private static $normalizedPathCache = null;
+ private static ?View $defaultInstance = null;
- private static $listeningForProviders = false;
+ private static ?CappedMemoryCache $normalizedPathCache = null;
/** @var string[]|null */
- private static $blacklist = null;
+ private static ?array $blacklist = null;
/**
* classname which used for hooks handling
@@ -186,22 +178,18 @@ class Filesystem {
public const signal_param_mount_type = 'mounttype';
public const signal_param_users = 'users';
- /**
- * @var \OC\Files\Storage\StorageFactory $loader
- */
- private static $loader;
+ private static ?\OC\Files\Storage\StorageFactory $loader = null;
- /** @var bool */
- private static $logWarningWhenAddingStorageWrapper = true;
+ private static bool $logWarningWhenAddingStorageWrapper = true;
/**
* @param bool $shouldLog
* @return bool previous value
* @internal
*/
- public static function logWarningWhenAddingStorageWrapper($shouldLog) {
+ public static function logWarningWhenAddingStorageWrapper(bool $shouldLog): bool {
$previousValue = self::$logWarningWhenAddingStorageWrapper;
- self::$logWarningWhenAddingStorageWrapper = (bool) $shouldLog;
+ self::$logWarningWhenAddingStorageWrapper = $shouldLog;
return $previousValue;
}
@@ -232,18 +220,17 @@ class Filesystem {
*/
public static function getLoader() {
if (!self::$loader) {
- self::$loader = \OC::$server->query(IStorageFactory::class);
+ self::$loader = \OC::$server->get(IStorageFactory::class);
}
return self::$loader;
}
/**
* Returns the mount manager
- *
- * @return \OC\Files\Mount\Manager
*/
- public static function getMountManager($user = '') {
+ public static function getMountManager(): Mount\Manager {
self::initMountManager();
+ assert(self::$mounts !== null);
return self::$mounts;
}
@@ -313,14 +300,14 @@ class Filesystem {
* resolve a path to a storage and internal path
*
* @param string $path
* @return array an array consisting of the storage and the internal path
*/
- public static function resolvePath($path) {
+ public static function resolvePath($path): array {
$mount = self::getMountManager()->find($path);
return [$mount->getStorage(), rtrim($mount->getInternalPath($path), '/')];
}
- public static function init($user, $root) {
+ public static function init(string|IUser|null $user, string $root): bool {
if (self::$defaultInstance) {
return false;
}
@@ -332,7 +319,7 @@ class Filesystem {
return true;
}
- public static function initInternal($root) {
+ public static function initInternal(string $root): bool {
if (self::$defaultInstance) {
return false;
}
@@ -342,32 +329,28 @@ class Filesystem {
$eventDispatcher = \OC::$server->get(IEventDispatcher::class);
$eventDispatcher->addListener(FilesystemTornDownEvent::class, function () {
self::$defaultInstance = null;
- self::$usersSetup = [];
self::$loaded = false;
});
- if (!self::$mounts) {
- self::$mounts = \OC::$server->getMountManager();
- }
+ self::initMountManager();
self::$loaded = true;
return true;
}
- public static function initMountManager() {
+ public static function initMountManager(): void {
if (!self::$mounts) {
- self::$mounts = \OC::$server->getMountManager();
+ self::$mounts = \OC::$server->get(IMountManager::class);
}
}
/**
* Initialize system and personal mount points for a user
*
- * @param string|IUser|null $user
* @throws \OC\User\NoUserException if the user is not available
*/
- public static function initMountPoints($user = '') {
+ public static function initMountPoints(string|IUser|null $user = ''): void {
/** @var IUserManager $userManager */
$userManager = \OC::$server->get(IUserManager::class);
@@ -382,11 +365,9 @@ class Filesystem {
}
/**
- * get the default filesystem view
- *
- * @return View
+ * Get the default filesystem view
*/
- public static function getView() {
+ public static function getView(): ?View {
if (!self::$defaultInstance) {
/** @var IUserSession $session */
$session = \OC::$server->get(IUserSession::class);
@@ -313,14 +300,14 @@ class Filesystem {
*
* @param string $path
- * @return array an array consisting of the storage and the internal path
+ * @return array{?\OCP\Files\Storage\IStorage, string} an array consisting of the storage and the internal path
*/